Class: Google::Apis::MerchantapiProductsV1beta::CloudExportAdditionalProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/merchantapi_products_v1beta/classes.rb,
lib/google/apis/merchantapi_products_v1beta/representations.rb,
lib/google/apis/merchantapi_products_v1beta/representations.rb

Overview

Product property for the Cloud Retail API. For example, properties for a TV product could be "Screen-Resolution" or "Screen-Size".

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CloudExportAdditionalProperties

Returns a new instance of CloudExportAdditionalProperties.



822
823
824
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 822

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bool_valueBoolean Also known as: bool_value?

Boolean value of the given property. For example for a TV product, "True" or " False" if the screen is UHD. Corresponds to the JSON property boolValue

Returns:

  • (Boolean)


776
777
778
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 776

def bool_value
  @bool_value
end

#float_valueArray<Float>

Float values of the given property. For example for a TV product 1.2345. Maximum repeatedness of this value is 400. Values are stored in an arbitrary but consistent order. Corresponds to the JSON property floatValue

Returns:

  • (Array<Float>)


784
785
786
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 784

def float_value
  @float_value
end

#int_valueArray<Fixnum>

Integer values of the given property. For example, 1080 for a TV product's Screen Resolution. Maximum repeatedness of this value is 400. Values are stored in an arbitrary but consistent order. Corresponds to the JSON property intValue

Returns:

  • (Array<Fixnum>)


791
792
793
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 791

def int_value
  @int_value
end

#max_valueFloat

Maximum float value of the given property. For example for a TV product 100.00. Corresponds to the JSON property maxValue

Returns:

  • (Float)


796
797
798
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 796

def max_value
  @max_value
end

#min_valueFloat

Minimum float value of the given property. For example for a TV product 1.00. Corresponds to the JSON property minValue

Returns:

  • (Float)


801
802
803
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 801

def min_value
  @min_value
end

#property_nameString

Name of the given property. For example, "Screen-Resolution" for a TV product. Maximum string size is 256 characters. Corresponds to the JSON property propertyName

Returns:

  • (String)


807
808
809
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 807

def property_name
  @property_name
end

#text_valueArray<String>

Text value of the given property. For example, "8K(UHD)" could be a text value for a TV product. Maximum repeatedness of this value is 400. Values are stored in an arbitrary but consistent order. Maximum string size is 256 characters. Corresponds to the JSON property textValue

Returns:

  • (Array<String>)


814
815
816
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 814

def text_value
  @text_value
end

#unit_codeString

Unit of the given property. For example, "Pixels" for a TV product. Maximum string size is 256B. Corresponds to the JSON property unitCode

Returns:

  • (String)


820
821
822
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 820

def unit_code
  @unit_code
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



827
828
829
830
831
832
833
834
835
836
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 827

def update!(**args)
  @bool_value = args[:bool_value] if args.key?(:bool_value)
  @float_value = args[:float_value] if args.key?(:float_value)
  @int_value = args[:int_value] if args.key?(:int_value)
  @max_value = args[:max_value] if args.key?(:max_value)
  @min_value = args[:min_value] if args.key?(:min_value)
  @property_name = args[:property_name] if args.key?(:property_name)
  @text_value = args[:text_value] if args.key?(:text_value)
  @unit_code = args[:unit_code] if args.key?(:unit_code)
end