Class: Google::Apis::MerchantapiProductsV1beta::FreeShippingThreshold

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/merchantapi_products_v1beta/classes.rb,
lib/google/apis/merchantapi_products_v1beta/representations.rb,
lib/google/apis/merchantapi_products_v1beta/representations.rb

Overview

Conditions to be met for a product to have free shipping.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FreeShippingThreshold

Returns a new instance of FreeShippingThreshold.



942
943
944
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 942

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#countryString

The CLDR territory code of the country to which an item will ship. Corresponds to the JSON property country

Returns:

  • (String)


935
936
937
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 935

def country
  @country
end

#price_thresholdGoogle::Apis::MerchantapiProductsV1beta::Price

The price represented as a number and currency. Corresponds to the JSON property priceThreshold



940
941
942
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 940

def price_threshold
  @price_threshold
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



947
948
949
950
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 947

def update!(**args)
  @country = args[:country] if args.key?(:country)
  @price_threshold = args[:price_threshold] if args.key?(:price_threshold)
end