Class: Google::Apis::MerchantapiProductsV1beta::ItemLevelIssue

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/merchantapi_products_v1beta/classes.rb,
lib/google/apis/merchantapi_products_v1beta/representations.rb,
lib/google/apis/merchantapi_products_v1beta/representations.rb

Overview

The ItemLevelIssue of the product status.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ItemLevelIssue

Returns a new instance of ItemLevelIssue.



1069
1070
1071
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 1069

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#applicable_countriesArray<String>

List of country codes (ISO 3166-1 alpha-2) where issue applies to the offer. Corresponds to the JSON property applicableCountries

Returns:

  • (Array<String>)


1027
1028
1029
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 1027

def applicable_countries
  @applicable_countries
end

#attributeString

The attribute's name, if the issue is caused by a single attribute. Corresponds to the JSON property attribute

Returns:

  • (String)


1032
1033
1034
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 1032

def attribute
  @attribute
end

#codeString

The error code of the issue. Corresponds to the JSON property code

Returns:

  • (String)


1037
1038
1039
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 1037

def code
  @code
end

#descriptionString

A short issue description in English. Corresponds to the JSON property description

Returns:

  • (String)


1042
1043
1044
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 1042

def description
  @description
end

#detailString

A detailed issue description in English. Corresponds to the JSON property detail

Returns:

  • (String)


1047
1048
1049
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 1047

def detail
  @detail
end

#documentationString

The URL of a web page to help with resolving this issue. Corresponds to the JSON property documentation

Returns:

  • (String)


1052
1053
1054
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 1052

def documentation
  @documentation
end

#reporting_contextString

The reporting context the issue applies to. Corresponds to the JSON property reportingContext

Returns:

  • (String)


1057
1058
1059
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 1057

def reporting_context
  @reporting_context
end

#resolutionString

Whether the issue can be resolved by the business. Corresponds to the JSON property resolution

Returns:

  • (String)


1062
1063
1064
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 1062

def resolution
  @resolution
end

#severityString

How this issue affects serving of the offer. Corresponds to the JSON property severity

Returns:

  • (String)


1067
1068
1069
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 1067

def severity
  @severity
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1074
1075
1076
1077
1078
1079
1080
1081
1082
1083
1084
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 1074

def update!(**args)
  @applicable_countries = args[:applicable_countries] if args.key?(:applicable_countries)
  @attribute = args[:attribute] if args.key?(:attribute)
  @code = args[:code] if args.key?(:code)
  @description = args[:description] if args.key?(:description)
  @detail = args[:detail] if args.key?(:detail)
  @documentation = args[:documentation] if args.key?(:documentation)
  @reporting_context = args[:reporting_context] if args.key?(:reporting_context)
  @resolution = args[:resolution] if args.key?(:resolution)
  @severity = args[:severity] if args.key?(:severity)
end