Class: Google::Apis::MerchantapiProductsV1beta::ProductDetail
- Inherits:
-
Object
- Object
- Google::Apis::MerchantapiProductsV1beta::ProductDetail
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/merchantapi_products_v1beta/classes.rb,
lib/google/apis/merchantapi_products_v1beta/representations.rb,
lib/google/apis/merchantapi_products_v1beta/representations.rb
Overview
The product details.
Instance Attribute Summary collapse
-
#attribute_name ⇒ String
The name of the product detail.
-
#attribute_value ⇒ String
The value of the product detail.
-
#section_name ⇒ String
The section header used to group a set of product details.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ProductDetail
constructor
A new instance of ProductDetail.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ProductDetail
Returns a new instance of ProductDetail.
1432 1433 1434 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 1432 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attribute_name ⇒ String
The name of the product detail.
Corresponds to the JSON property attributeName
1420 1421 1422 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 1420 def attribute_name @attribute_name end |
#attribute_value ⇒ String
The value of the product detail.
Corresponds to the JSON property attributeValue
1425 1426 1427 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 1425 def attribute_value @attribute_value end |
#section_name ⇒ String
The section header used to group a set of product details.
Corresponds to the JSON property sectionName
1430 1431 1432 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 1430 def section_name @section_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1437 1438 1439 1440 1441 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 1437 def update!(**args) @attribute_name = args[:attribute_name] if args.key?(:attribute_name) @attribute_value = args[:attribute_value] if args.key?(:attribute_value) @section_name = args[:section_name] if args.key?(:section_name) end |