Class: Google::Apis::MerchantapiProductsV1beta::ProductStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/merchantapi_products_v1beta/classes.rb,
lib/google/apis/merchantapi_products_v1beta/representations.rb,
lib/google/apis/merchantapi_products_v1beta/representations.rb

Overview

The status of a product, data validation issues, that is, information about a product computed asynchronously.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ProductStatus

Returns a new instance of ProductStatus.



1672
1673
1674
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 1672

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_dateString

Date on which the item has been created, in ISO 8601 format. Corresponds to the JSON property creationDate

Returns:

  • (String)


1648
1649
1650
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 1648

def creation_date
  @creation_date
end

#destination_statusesArray<Google::Apis::MerchantapiProductsV1beta::DestinationStatus>

The intended destinations for the product. Corresponds to the JSON property destinationStatuses



1653
1654
1655
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 1653

def destination_statuses
  @destination_statuses
end

#google_expiration_dateString

Date on which the item expires, in ISO 8601 format. Corresponds to the JSON property googleExpirationDate

Returns:

  • (String)


1659
1660
1661
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 1659

def google_expiration_date
  @google_expiration_date
end

#item_level_issuesArray<Google::Apis::MerchantapiProductsV1beta::ItemLevelIssue>

A list of all issues associated with the product. Corresponds to the JSON property itemLevelIssues



1664
1665
1666
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 1664

def item_level_issues
  @item_level_issues
end

#last_update_dateString

Date on which the item has been last updated, in ISO 8601 format. Corresponds to the JSON property lastUpdateDate

Returns:

  • (String)


1670
1671
1672
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 1670

def last_update_date
  @last_update_date
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1677
1678
1679
1680
1681
1682
1683
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 1677

def update!(**args)
  @creation_date = args[:creation_date] if args.key?(:creation_date)
  @destination_statuses = args[:destination_statuses] if args.key?(:destination_statuses)
  @google_expiration_date = args[:google_expiration_date] if args.key?(:google_expiration_date)
  @item_level_issues = args[:item_level_issues] if args.key?(:item_level_issues)
  @last_update_date = args[:last_update_date] if args.key?(:last_update_date)
end