Class: Google::Apis::MerchantapiProductsV1beta::Shipping
- Inherits:
-
Object
- Object
- Google::Apis::MerchantapiProductsV1beta::Shipping
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/merchantapi_products_v1beta/classes.rb,
lib/google/apis/merchantapi_products_v1beta/representations.rb,
lib/google/apis/merchantapi_products_v1beta/representations.rb
Overview
The Shipping of the product.
Instance Attribute Summary collapse
-
#country ⇒ String
The CLDR territory code of the country to which an item will ship.
-
#handling_cutoff_time ⇒ String
The handling cutoff time until which an order has to be placed to be processed in the same day.
-
#handling_cutoff_timezone ⇒ String
Timezone identifier For example
Europe/Zurich. -
#location_group_name ⇒ String
The location where the shipping is applicable, represented by a location group name.
-
#location_id ⇒ Fixnum
The numeric ID of a location that the shipping rate applies to as defined in the AdWords API.
-
#loyalty_program_label ⇒ String
Optional.
-
#loyalty_tier_label ⇒ String
Optional.
-
#max_handling_time ⇒ Fixnum
Maximum handling time (inclusive) between when the order is received and shipped in business days.
-
#max_transit_time ⇒ Fixnum
Maximum transit time (inclusive) between when the order has shipped and when it is delivered in business days.
-
#min_handling_time ⇒ Fixnum
Minimum handling time (inclusive) between when the order is received and shipped in business days.
-
#min_transit_time ⇒ Fixnum
Minimum transit time (inclusive) between when the order has shipped and when it is delivered in business days.
-
#postal_code ⇒ String
The postal code range that the shipping rate applies to, represented by a postal code, a postal code prefix followed by a * wildcard, a range between two postal codes or two postal code prefixes of equal length.
-
#price ⇒ Google::Apis::MerchantapiProductsV1beta::Price
The price represented as a number and currency.
-
#region ⇒ String
The geographic region to which a shipping rate applies.
-
#service ⇒ String
A free-form description of the service class or delivery speed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Shipping
constructor
A new instance of Shipping.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Shipping
Returns a new instance of Shipping.
1989 1990 1991 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 1989 def initialize(**args) update!(**args) end |
Instance Attribute Details
#country ⇒ String
The CLDR territory code of the country to which an item will ship.
Corresponds to the JSON property country
1881 1882 1883 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 1881 def country @country end |
#handling_cutoff_time ⇒ String
The handling cutoff time until which an order has to be placed to be processed
in the same day. This is a string in format of HHMM (e.g. 1530) for 3:30 PM.
If not configured, the cutoff time will be defaulted to 8AM PST and
handling_cutoff_timezone will be ignored.
Corresponds to the JSON property handlingCutoffTime
1889 1890 1891 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 1889 def handling_cutoff_time @handling_cutoff_time end |
#handling_cutoff_timezone ⇒ String
Timezone identifier For example Europe/Zurich. This field only
applies if handling_cutoff_time is set. If handling_cutoff_time is set but
this field is not set, the shipping destination timezone will be used. If both
fields are not set, the handling cutoff time will default to 8AM PST.
Corresponds to the JSON property handlingCutoffTimezone
1898 1899 1900 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 1898 def handling_cutoff_timezone @handling_cutoff_timezone end |
#location_group_name ⇒ String
The location where the shipping is applicable, represented by a location group
name.
Corresponds to the JSON property locationGroupName
1904 1905 1906 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 1904 def location_group_name @location_group_name end |
#location_id ⇒ Fixnum
The numeric ID of a location that the shipping rate applies to as defined in
the AdWords API.
Corresponds to the JSON property locationId
1911 1912 1913 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 1911 def location_id @location_id end |
#loyalty_program_label ⇒ String
Optional. The label of the loyalty program. Must match one of the program labels set in
loyalty_programs. When set (in combination with loyalty_tier_label), this shipping option is only
applicable to loyalty program members of the specified tier.
Corresponds to the JSON property loyaltyProgramLabel
1920 1921 1922 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 1920 def loyalty_program_label @loyalty_program_label end |
#loyalty_tier_label ⇒ String
Optional. The label of the loyalty tier within the loyalty program. Must match one of the tiers set in
the loyalty_programs. When set (in combination with loyalty_program_label), this shipping option is
only applicable to loyalty program members of the specified tier.
Corresponds to the JSON property loyaltyTierLabel
1929 1930 1931 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 1929 def loyalty_tier_label @loyalty_tier_label end |
#max_handling_time ⇒ Fixnum
Maximum handling time (inclusive) between when the order is received and
shipped in business days. 0 means that the order is shipped on the same day as
it is received if it happens before the cut-off time. Both maxHandlingTime and
maxTransitTime are required if providing shipping speeds. minHandlingTime is
optional if maxHandlingTime is present.
Corresponds to the JSON property maxHandlingTime
1938 1939 1940 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 1938 def max_handling_time @max_handling_time end |
#max_transit_time ⇒ Fixnum
Maximum transit time (inclusive) between when the order has shipped and when
it is delivered in business days. 0 means that the order is delivered on the
same day as it ships. Both maxHandlingTime and maxTransitTime are required if
providing shipping speeds. minTransitTime is optional if maxTransitTime is
present.
Corresponds to the JSON property maxTransitTime
1947 1948 1949 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 1947 def max_transit_time @max_transit_time end |
#min_handling_time ⇒ Fixnum
Minimum handling time (inclusive) between when the order is received and
shipped in business days. 0 means that the order is shipped on the same day as
it is received if it happens before the cut-off time. minHandlingTime can only
be present together with maxHandlingTime; but it is not required if
maxHandlingTime is present.
Corresponds to the JSON property minHandlingTime
1956 1957 1958 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 1956 def min_handling_time @min_handling_time end |
#min_transit_time ⇒ Fixnum
Minimum transit time (inclusive) between when the order has shipped and when
it is delivered in business days. 0 means that the order is delivered on the
same day as it ships. minTransitTime can only be present together with
maxTransitTime; but it is not required if maxTransitTime is present.
Corresponds to the JSON property minTransitTime
1964 1965 1966 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 1964 def min_transit_time @min_transit_time end |
#postal_code ⇒ String
The postal code range that the shipping rate applies to, represented by a
postal code, a postal code prefix followed by a * wildcard, a range between
two postal codes or two postal code prefixes of equal length.
Corresponds to the JSON property postalCode
1971 1972 1973 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 1971 def postal_code @postal_code end |
#price ⇒ Google::Apis::MerchantapiProductsV1beta::Price
The price represented as a number and currency.
Corresponds to the JSON property price
1976 1977 1978 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 1976 def price @price end |
#region ⇒ String
The geographic region to which a shipping rate applies. See region for more information.
Corresponds to the JSON property region
1982 1983 1984 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 1982 def region @region end |
#service ⇒ String
A free-form description of the service class or delivery speed.
Corresponds to the JSON property service
1987 1988 1989 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 1987 def service @service end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1994 1995 1996 1997 1998 1999 2000 2001 2002 2003 2004 2005 2006 2007 2008 2009 2010 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 1994 def update!(**args) @country = args[:country] if args.key?(:country) @handling_cutoff_time = args[:handling_cutoff_time] if args.key?(:handling_cutoff_time) @handling_cutoff_timezone = args[:handling_cutoff_timezone] if args.key?(:handling_cutoff_timezone) @location_group_name = args[:location_group_name] if args.key?(:location_group_name) @location_id = args[:location_id] if args.key?(:location_id) @loyalty_program_label = args[:loyalty_program_label] if args.key?(:loyalty_program_label) @loyalty_tier_label = args[:loyalty_tier_label] if args.key?(:loyalty_tier_label) @max_handling_time = args[:max_handling_time] if args.key?(:max_handling_time) @max_transit_time = args[:max_transit_time] if args.key?(:max_transit_time) @min_handling_time = args[:min_handling_time] if args.key?(:min_handling_time) @min_transit_time = args[:min_transit_time] if args.key?(:min_transit_time) @postal_code = args[:postal_code] if args.key?(:postal_code) @price = args[:price] if args.key?(:price) @region = args[:region] if args.key?(:region) @service = args[:service] if args.key?(:service) end |