Class: Google::Apis::MerchantapiProductsV1beta::Attributes
- Inherits:
-
Object
- Object
- Google::Apis::MerchantapiProductsV1beta::Attributes
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/merchantapi_products_v1beta/classes.rb,
lib/google/apis/merchantapi_products_v1beta/representations.rb,
lib/google/apis/merchantapi_products_v1beta/representations.rb
Overview
Attributes.
Instance Attribute Summary collapse
-
#additional_image_links ⇒ Array<String>
Additional URLs of images of the item.
-
#ads_grouping ⇒ String
Used to group items in an arbitrary way.
-
#ads_labels ⇒ Array<String>
Similar to ads_grouping, but only works on CPC.
-
#ads_redirect ⇒ String
Allows advertisers to override the item URL when the product is shown within the context of Product ads.
-
#adult ⇒ Boolean
(also: #adult?)
Set to true if the item is targeted towards adults.
-
#age_group ⇒ String
Target age group of the item.
-
#auto_pricing_min_price ⇒ Google::Apis::MerchantapiProductsV1beta::Price
The price represented as a number and currency.
-
#availability ⇒ String
Availability status of the item.
-
#availability_date ⇒ String
The day a pre-ordered product becomes available for delivery, in ISO 8601 format.
-
#brand ⇒ String
Brand of the item.
-
#canonical_link ⇒ String
URL for the canonical version of your item's landing page.
-
#certifications ⇒ Array<Google::Apis::MerchantapiProductsV1beta::Certification>
Product Certifications, for example for energy efficiency labeling of products recorded in the EU EPREL database.
-
#cloud_export_additional_properties ⇒ Array<Google::Apis::MerchantapiProductsV1beta::CloudExportAdditionalProperties>
Extra fields to export to the Cloud Retail program.
-
#color ⇒ String
Color of the item.
-
#condition ⇒ String
Condition or state of the item.
-
#cost_of_goods_sold ⇒ Google::Apis::MerchantapiProductsV1beta::Price
The price represented as a number and currency.
-
#custom_label0 ⇒ String
Custom label 0 for custom grouping of items in a Shopping campaign.
-
#custom_label1 ⇒ String
Custom label 1 for custom grouping of items in a Shopping campaign.
-
#custom_label2 ⇒ String
Custom label 2 for custom grouping of items in a Shopping campaign.
-
#custom_label3 ⇒ String
Custom label 3 for custom grouping of items in a Shopping campaign.
-
#custom_label4 ⇒ String
Custom label 4 for custom grouping of items in a Shopping campaign.
-
#description ⇒ String
Description of the item.
-
#disclosure_date ⇒ String
The date time when an offer becomes visible in search results across Google’s YouTube surfaces, in ISO 8601 format.
-
#display_ads_id ⇒ String
An identifier for an item for dynamic remarketing campaigns.
-
#display_ads_link ⇒ String
URL directly to your item's landing page for dynamic remarketing campaigns.
-
#display_ads_similar_ids ⇒ Array<String>
Advertiser-specified recommendations.
-
#display_ads_title ⇒ String
Title of an item for dynamic remarketing campaigns.
-
#display_ads_value ⇒ Float
Offer margin for dynamic remarketing campaigns.
-
#energy_efficiency_class ⇒ String
The energy efficiency class as defined in EU directive 2010/30/EU.
-
#excluded_destinations ⇒ Array<String>
Destinations also known as Marketing methods selections.
-
#expiration_date ⇒ String
Date on which the item should expire, as specified upon insertion, in ISO 8601 format.
-
#external_seller_id ⇒ String
Required for multi-seller accounts.
-
#free_shipping_threshold ⇒ Array<Google::Apis::MerchantapiProductsV1beta::FreeShippingThreshold>
Conditions to be met for a product to have free shipping.
-
#gender ⇒ String
Target gender of the item.
-
#google_product_category ⇒ String
Google's category of the item (see Google product taxonomy).
-
#gtin ⇒ Array<String>
Global Trade Item Numbers (GTIN) of the item.
-
#gtins ⇒ Array<String>
A list of Global Trade Item Numbers (GTIN) of the item.
-
#identifier_exists ⇒ Boolean
(also: #identifier_exists?)
Set this value to false when the item does not have unique product identifiers appropriate to its category, such as GTIN, MPN, and brand.
-
#image_link ⇒ String
URL of an image of the item.
-
#included_destinations ⇒ Array<String>
Destinations also known as Marketing methods selections.
-
#installment ⇒ Google::Apis::MerchantapiProductsV1beta::Installment
A message that represents installment.
-
#is_bundle ⇒ Boolean
(also: #is_bundle?)
Whether the item is a business-defined sub-API.
-
#item_group_id ⇒ String
Shared identifier for all variants of the same product.
-
#lifestyle_image_links ⇒ Array<String>
Additional URLs of lifestyle images of the item, used to explicitly identify images that showcase your item in a real-world context.
-
#link ⇒ String
URL directly linking to your item's page on your online store.
-
#link_template ⇒ String
Link template for business hosted local storefront.
-
#loyalty_points ⇒ Google::Apis::MerchantapiProductsV1beta::LoyaltyPoints
A message that represents loyalty points.
-
#loyalty_programs ⇒ Array<Google::Apis::MerchantapiProductsV1beta::LoyaltyProgram>
A list of loyalty program information that is used to surface loyalty benefits (for example, better pricing, points, etc) to the user of this item.
-
#material ⇒ String
The material of which the item is made.
-
#max_energy_efficiency_class ⇒ String
The energy efficiency class as defined in EU directive 2010/30/EU.
-
#max_handling_time ⇒ Fixnum
Maximal product handling time (in business days).
-
#maximum_retail_price ⇒ Google::Apis::MerchantapiProductsV1beta::Price
The price represented as a number and currency.
-
#min_energy_efficiency_class ⇒ String
The energy efficiency class as defined in EU directive 2010/30/EU.
-
#min_handling_time ⇒ Fixnum
Minimal product handling time (in business days).
-
#mobile_link ⇒ String
URL for the mobile-optimized version of your item's landing page.
-
#mobile_link_template ⇒ String
Link template for business hosted local storefront optimized for mobile devices.
-
#mpn ⇒ String
Manufacturer Part Number (MPN) of the item.
-
#multipack ⇒ Fixnum
The number of identical products in a business-defined multipack.
-
#pattern ⇒ String
The item's pattern.
-
#pause ⇒ String
Publication of this item will be temporarily paused.
-
#pickup_method ⇒ String
The pickup option for the item.
-
#pickup_sla ⇒ String
Item store pickup timeline.
-
#price ⇒ Google::Apis::MerchantapiProductsV1beta::Price
The price represented as a number and currency.
-
#product_details ⇒ Array<Google::Apis::MerchantapiProductsV1beta::ProductDetail>
Technical specification or additional product details.
-
#product_height ⇒ Google::Apis::MerchantapiProductsV1beta::ProductDimension
The dimension of the product.
-
#product_highlights ⇒ Array<String>
Bullet points describing the most relevant product highlights.
-
#product_length ⇒ Google::Apis::MerchantapiProductsV1beta::ProductDimension
The dimension of the product.
-
#product_types ⇒ Array<String>
Categories of the item (formatted as in product data specification).
-
#product_weight ⇒ Google::Apis::MerchantapiProductsV1beta::ProductWeight
The weight of the product.
-
#product_width ⇒ Google::Apis::MerchantapiProductsV1beta::ProductDimension
The dimension of the product.
-
#promotion_ids ⇒ Array<String>
The unique ID of a promotion.
-
#sale_price ⇒ Google::Apis::MerchantapiProductsV1beta::Price
The price represented as a number and currency.
-
#sale_price_effective_date ⇒ Google::Apis::MerchantapiProductsV1beta::Interval
Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive).
-
#sell_on_google_quantity ⇒ Fixnum
The quantity of the product that is available for selling on Google.
-
#shipping ⇒ Array<Google::Apis::MerchantapiProductsV1beta::Shipping>
Shipping rules.
-
#shipping_height ⇒ Google::Apis::MerchantapiProductsV1beta::ShippingDimension
The ShippingDimension of the product.
-
#shipping_label ⇒ String
The shipping label of the product, used to group product in account-level shipping rules.
-
#shipping_length ⇒ Google::Apis::MerchantapiProductsV1beta::ShippingDimension
The ShippingDimension of the product.
-
#shipping_weight ⇒ Google::Apis::MerchantapiProductsV1beta::ShippingWeight
The ShippingWeight of the product.
-
#shipping_width ⇒ Google::Apis::MerchantapiProductsV1beta::ShippingDimension
The ShippingDimension of the product.
-
#shopping_ads_excluded_countries ⇒ Array<String>
List of country codes (ISO 3166-1 alpha-2) to exclude the offer from Shopping Ads destination.
-
#size ⇒ String
Size of the item.
-
#size_system ⇒ String
System in which the size is specified.
-
#size_types ⇒ Array<String>
The cut of the item.
-
#structured_description ⇒ Google::Apis::MerchantapiProductsV1beta::ProductStructuredDescription
Structured description, for algorithmically (AI)-generated descriptions.
-
#structured_title ⇒ Google::Apis::MerchantapiProductsV1beta::ProductStructuredTitle
Structured title, for algorithmically (AI)-generated titles.
-
#subscription_cost ⇒ Google::Apis::MerchantapiProductsV1beta::SubscriptionCost
The SubscriptionCost of the product.
-
#sustainability_incentives ⇒ Array<Google::Apis::MerchantapiProductsV1beta::ProductSustainabilityIncentive>
The list of sustainability incentive programs.
-
#tax_category ⇒ String
The tax category of the product.
-
#taxes ⇒ Array<Google::Apis::MerchantapiProductsV1beta::Tax>
Tax information.
-
#title ⇒ String
Title of the item.
-
#transit_time_label ⇒ String
The transit time label of the product, used to group product in account-level transit time tables.
-
#unit_pricing_base_measure ⇒ Google::Apis::MerchantapiProductsV1beta::UnitPricingBaseMeasure
The UnitPricingBaseMeasure of the product.
-
#unit_pricing_measure ⇒ Google::Apis::MerchantapiProductsV1beta::UnitPricingMeasure
The UnitPricingMeasure of the product.
-
#virtual_model_link ⇒ String
URL of the 3D image of the item.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Attributes
constructor
A new instance of Attributes.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Attributes
Returns a new instance of Attributes.
590 591 592 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 590 def initialize(**args) update!(**args) end |
Instance Attribute Details
#additional_image_links ⇒ Array<String>
Additional URLs of images of the item.
Corresponds to the JSON property additionalImageLinks
32 33 34 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 32 def additional_image_links @additional_image_links end |
#ads_grouping ⇒ String
Used to group items in an arbitrary way. Only for CPA, discouraged otherwise.
For more information, see Display ads attribute.
Corresponds to the JSON property adsGrouping
39 40 41 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 39 def ads_grouping @ads_grouping end |
#ads_labels ⇒ Array<String>
Similar to ads_grouping, but only works on CPC.
Corresponds to the JSON property adsLabels
44 45 46 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 44 def ads_labels @ads_labels end |
#ads_redirect ⇒ String
Allows advertisers to override the item URL when the product is shown within
the context of Product ads.
Corresponds to the JSON property adsRedirect
50 51 52 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 50 def ads_redirect @ads_redirect end |
#adult ⇒ Boolean Also known as: adult?
Set to true if the item is targeted towards adults.
Corresponds to the JSON property adult
55 56 57 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 55 def adult @adult end |
#age_group ⇒ String
Target age group of the
item.
Corresponds to the JSON property ageGroup
62 63 64 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 62 def age_group @age_group end |
#auto_pricing_min_price ⇒ Google::Apis::MerchantapiProductsV1beta::Price
The price represented as a number and currency.
Corresponds to the JSON property autoPricingMinPrice
67 68 69 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 67 def auto_pricing_min_price @auto_pricing_min_price end |
#availability ⇒ String
Availability status of
the item. For example, "in_stock" or "out_of_stock".
Corresponds to the JSON property availability
73 74 75 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 73 def availability @availability end |
#availability_date ⇒ String
The day a pre-ordered product becomes available for delivery, in ISO 8601 format.
Corresponds to the JSON property availabilityDate
79 80 81 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 79 def availability_date @availability_date end |
#brand ⇒ String
Brand of the item. For
example, "Google".
Corresponds to the JSON property brand
85 86 87 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 85 def brand @brand end |
#canonical_link ⇒ String
URL for the canonical version of your item's landing page.
Corresponds to the JSON property canonicalLink
90 91 92 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 90 def canonical_link @canonical_link end |
#certifications ⇒ Array<Google::Apis::MerchantapiProductsV1beta::Certification>
Product Certifications, for example for energy efficiency labeling of products
recorded in the EU EPREL database.
See the Help Center
article for more information.
Corresponds to the JSON property certifications
98 99 100 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 98 def certifications @certifications end |
#cloud_export_additional_properties ⇒ Array<Google::Apis::MerchantapiProductsV1beta::CloudExportAdditionalProperties>
Extra fields to export to the Cloud Retail program.
Corresponds to the JSON property cloudExportAdditionalProperties
103 104 105 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 103 def cloud_export_additional_properties @cloud_export_additional_properties end |
#color ⇒ String
Color of the item. For
example, "red".
Corresponds to the JSON property color
109 110 111 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 109 def color @color end |
#condition ⇒ String
Condition or state of
the item. For example, "new" or "used".
Corresponds to the JSON property condition
115 116 117 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 115 def condition @condition end |
#cost_of_goods_sold ⇒ Google::Apis::MerchantapiProductsV1beta::Price
The price represented as a number and currency.
Corresponds to the JSON property costOfGoodsSold
120 121 122 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 120 def cost_of_goods_sold @cost_of_goods_sold end |
#custom_label0 ⇒ String
Custom label 0 for
custom grouping of items in a Shopping campaign.
Corresponds to the JSON property customLabel0
126 127 128 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 126 def custom_label0 @custom_label0 end |
#custom_label1 ⇒ String
Custom label 1 for
custom grouping of items in a Shopping campaign.
Corresponds to the JSON property customLabel1
132 133 134 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 132 def custom_label1 @custom_label1 end |
#custom_label2 ⇒ String
Custom label 2 for
custom grouping of items in a Shopping campaign.
Corresponds to the JSON property customLabel2
138 139 140 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 138 def custom_label2 @custom_label2 end |
#custom_label3 ⇒ String
Custom label 3 for
custom grouping of items in a Shopping campaign.
Corresponds to the JSON property customLabel3
144 145 146 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 144 def custom_label3 @custom_label3 end |
#custom_label4 ⇒ String
Custom label 4 for
custom grouping of items in a Shopping campaign.
Corresponds to the JSON property customLabel4
150 151 152 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 150 def custom_label4 @custom_label4 end |
#description ⇒ String
Description of the item.
Corresponds to the JSON property description
155 156 157 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 155 def description @description end |
#disclosure_date ⇒ String
The date time when an offer becomes visible in search results across Google’s
YouTube surfaces, in ISO 8601 format.
See Disclosure date
for more information.
Corresponds to the JSON property disclosureDate
163 164 165 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 163 def disclosure_date @disclosure_date end |
#display_ads_id ⇒ String
An identifier for an item for dynamic remarketing campaigns.
Corresponds to the JSON property displayAdsId
168 169 170 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 168 def display_ads_id @display_ads_id end |
#display_ads_link ⇒ String
URL directly to your item's landing page for dynamic remarketing campaigns.
Corresponds to the JSON property displayAdsLink
173 174 175 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 173 def display_ads_link @display_ads_link end |
#display_ads_similar_ids ⇒ Array<String>
Advertiser-specified recommendations. For more information, see Display ads
attribute specification.
Corresponds to the JSON property displayAdsSimilarIds
179 180 181 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 179 def display_ads_similar_ids @display_ads_similar_ids end |
#display_ads_title ⇒ String
Title of an item for dynamic remarketing campaigns.
Corresponds to the JSON property displayAdsTitle
184 185 186 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 184 def display_ads_title @display_ads_title end |
#display_ads_value ⇒ Float
Offer margin for dynamic remarketing campaigns. For more information, see
Display ads attribute.
Corresponds to the JSON property displayAdsValue
190 191 192 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 190 def display_ads_value @display_ads_value end |
#energy_efficiency_class ⇒ String
The energy efficiency class as defined in EU directive 2010/30/EU.
Corresponds to the JSON property energyEfficiencyClass
195 196 197 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 195 def energy_efficiency_class @energy_efficiency_class end |
#excluded_destinations ⇒ Array<String>
Destinations also known as Marketing methods selections. The list of destinations to exclude for
this target (corresponds to unchecked check boxes in Merchant Center). For
more information, see Excluded destination. Note: We recommend setting destinations on
datasources level for most use cases. Use this field within products to only
setup exceptions.
Corresponds to the JSON property excludedDestinations
206 207 208 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 206 def excluded_destinations @excluded_destinations end |
#expiration_date ⇒ String
Date on which the item should expire, as specified upon insertion, in ISO
8601 format. The actual expiration
date is exposed in productstatuses as googleExpirationDate and might be earlier if expirationDate
is too far in the future.
Corresponds to the JSON property expirationDate
215 216 217 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 215 def expiration_date @expiration_date end |
#external_seller_id ⇒ String
Required for multi-seller accounts. Use this attribute if you're a marketplace
uploading products for various sellers to your multi-seller account.
Corresponds to the JSON property externalSellerId
221 222 223 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 221 def external_seller_id @external_seller_id end |
#free_shipping_threshold ⇒ Array<Google::Apis::MerchantapiProductsV1beta::FreeShippingThreshold>
Conditions to be met for a product to have free shipping.
Corresponds to the JSON property freeShippingThreshold
226 227 228 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 226 def free_shipping_threshold @free_shipping_threshold end |
#gender ⇒ String
Target gender of the
item. For example, "male" or "female".
Corresponds to the JSON property gender
232 233 234 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 232 def gender @gender end |
#google_product_category ⇒ String
Google's category of the item (see Google product taxonomy). When querying products, this field will
contain the user provided value. There is currently no way to get back the
auto assigned google product categories through the API.
Corresponds to the JSON property googleProductCategory
240 241 242 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 240 def google_product_category @google_product_category end |
#gtin ⇒ Array<String>
Global Trade Item Numbers (GTIN) of the item. You can provide up to 10 GTINs. Deprecated: Use gtins
instead.
Corresponds to the JSON property gtin
247 248 249 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 247 def gtin @gtin end |
#gtins ⇒ Array<String>
A list of Global Trade Item Numbers (GTIN) of the item. You can provide up to 10 GTINs.
Corresponds to the JSON property gtins
253 254 255 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 253 def gtins @gtins end |
#identifier_exists ⇒ Boolean Also known as: identifier_exists?
Set this value to false when the item does not have unique product identifiers
appropriate to its category, such as GTIN, MPN, and brand. Defaults to true,
if not provided.
Corresponds to the JSON property identifierExists
260 261 262 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 260 def identifier_exists @identifier_exists end |
#image_link ⇒ String
URL of an image of the item.
Corresponds to the JSON property imageLink
266 267 268 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 266 def image_link @image_link end |
#included_destinations ⇒ Array<String>
Destinations also known as Marketing methods selections. The list of destinations to include for
this target (corresponds to checked check boxes in Merchant Center). Default
destinations are always included unless provided in excludedDestinations.
For more information, see Included destination. Note: We recommend setting destinations on
datasources level for most use cases. Use this field within products to only
setup exceptions.
Corresponds to the JSON property includedDestinations
278 279 280 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 278 def included_destinations @included_destinations end |
#installment ⇒ Google::Apis::MerchantapiProductsV1beta::Installment
A message that represents installment.
Corresponds to the JSON property installment
283 284 285 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 283 def installment @installment end |
#is_bundle ⇒ Boolean Also known as: is_bundle?
Whether the item is a business-defined sub-API. A sub-API is a custom grouping of different
products sold by a business for a single price.
Corresponds to the JSON property isBundle
290 291 292 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 290 def is_bundle @is_bundle end |
#item_group_id ⇒ String
Shared identifier for all variants of the same product.
Corresponds to the JSON property itemGroupId
296 297 298 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 296 def item_group_id @item_group_id end |
#lifestyle_image_links ⇒ Array<String>
Additional URLs of lifestyle images of the item, used to explicitly identify
images that showcase your item in a real-world context. See the Help Center
article for more
information.
Corresponds to the JSON property lifestyleImageLinks
304 305 306 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 304 def lifestyle_image_links @lifestyle_image_links end |
#link ⇒ String
URL directly linking to your item's page on your online store.
Corresponds to the JSON property link
309 310 311 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 309 def link @link end |
#link_template ⇒ String
Link template for
business hosted local storefront.
Corresponds to the JSON property linkTemplate
315 316 317 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 315 def link_template @link_template end |
#loyalty_points ⇒ Google::Apis::MerchantapiProductsV1beta::LoyaltyPoints
A message that represents loyalty points.
Corresponds to the JSON property loyaltyPoints
320 321 322 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 320 def loyalty_points @loyalty_points end |
#loyalty_programs ⇒ Array<Google::Apis::MerchantapiProductsV1beta::LoyaltyProgram>
A list of loyalty program information that is used to surface loyalty benefits
(for example, better pricing, points, etc) to the user of this item.
Corresponds to the JSON property loyaltyPrograms
326 327 328 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 326 def loyalty_programs @loyalty_programs end |
#material ⇒ String
The material of which
the item is made. For example, "Leather" or "Cotton".
Corresponds to the JSON property material
332 333 334 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 332 def material @material end |
#max_energy_efficiency_class ⇒ String
The energy efficiency class as defined in EU directive 2010/30/EU.
Corresponds to the JSON property maxEnergyEfficiencyClass
337 338 339 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 337 def max_energy_efficiency_class @max_energy_efficiency_class end |
#max_handling_time ⇒ Fixnum
Maximal product handling time (in business days).
Corresponds to the JSON property maxHandlingTime
342 343 344 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 342 def max_handling_time @max_handling_time end |
#maximum_retail_price ⇒ Google::Apis::MerchantapiProductsV1beta::Price
The price represented as a number and currency.
Corresponds to the JSON property maximumRetailPrice
347 348 349 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 347 def maximum_retail_price @maximum_retail_price end |
#min_energy_efficiency_class ⇒ String
The energy efficiency class as defined in EU directive 2010/30/EU.
Corresponds to the JSON property minEnergyEfficiencyClass
352 353 354 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 352 def min_energy_efficiency_class @min_energy_efficiency_class end |
#min_handling_time ⇒ Fixnum
Minimal product handling time (in business days).
Corresponds to the JSON property minHandlingTime
357 358 359 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 357 def min_handling_time @min_handling_time end |
#mobile_link ⇒ String
URL for the mobile-optimized version of your item's landing page.
Corresponds to the JSON property mobileLink
362 363 364 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 362 def mobile_link @mobile_link end |
#mobile_link_template ⇒ String
Link template for
business hosted local storefront optimized for mobile devices.
Corresponds to the JSON property mobileLinkTemplate
368 369 370 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 368 def mobile_link_template @mobile_link_template end |
#mpn ⇒ String
Manufacturer Part Number (MPN) of the item.
Corresponds to the JSON property mpn
374 375 376 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 374 def mpn @mpn end |
#multipack ⇒ Fixnum
The number of identical products in a business-defined multipack.
Corresponds to the JSON property multipack
379 380 381 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 379 def multipack @multipack end |
#pattern ⇒ String
The item's pattern. For
example, polka dots.
Corresponds to the JSON property pattern
385 386 387 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 385 def pattern @pattern end |
#pause ⇒ String
Publication of this item will be temporarily paused.
Corresponds to the JSON property pause
391 392 393 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 391 def pause @pause end |
#pickup_method ⇒ String
The pickup option for
the item.
Corresponds to the JSON property pickupMethod
397 398 399 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 397 def pickup_method @pickup_method end |
#pickup_sla ⇒ String
Item store pickup timeline. For more information, see Pickup SLA.
Corresponds to the JSON property pickupSla
403 404 405 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 403 def pickup_sla @pickup_sla end |
#price ⇒ Google::Apis::MerchantapiProductsV1beta::Price
The price represented as a number and currency.
Corresponds to the JSON property price
408 409 410 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 408 def price @price end |
#product_details ⇒ Array<Google::Apis::MerchantapiProductsV1beta::ProductDetail>
Technical specification or additional product details.
Corresponds to the JSON property productDetails
413 414 415 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 413 def product_details @product_details end |
#product_height ⇒ Google::Apis::MerchantapiProductsV1beta::ProductDimension
The dimension of the product.
Corresponds to the JSON property productHeight
418 419 420 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 418 def product_height @product_height end |
#product_highlights ⇒ Array<String>
Bullet points describing the most relevant product highlights.
Corresponds to the JSON property productHighlights
424 425 426 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 424 def product_highlights @product_highlights end |
#product_length ⇒ Google::Apis::MerchantapiProductsV1beta::ProductDimension
The dimension of the product.
Corresponds to the JSON property productLength
429 430 431 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 429 def product_length @product_length end |
#product_types ⇒ Array<String>
Categories of the item (formatted as in product data specification).
Corresponds to the JSON property productTypes
435 436 437 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 435 def product_types @product_types end |
#product_weight ⇒ Google::Apis::MerchantapiProductsV1beta::ProductWeight
The weight of the product.
Corresponds to the JSON property productWeight
440 441 442 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 440 def product_weight @product_weight end |
#product_width ⇒ Google::Apis::MerchantapiProductsV1beta::ProductDimension
The dimension of the product.
Corresponds to the JSON property productWidth
445 446 447 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 445 def product_width @product_width end |
#promotion_ids ⇒ Array<String>
The unique ID of a promotion.
Corresponds to the JSON property promotionIds
450 451 452 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 450 def promotion_ids @promotion_ids end |
#sale_price ⇒ Google::Apis::MerchantapiProductsV1beta::Price
The price represented as a number and currency.
Corresponds to the JSON property salePrice
455 456 457 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 455 def sale_price @sale_price end |
#sale_price_effective_date ⇒ Google::Apis::MerchantapiProductsV1beta::Interval
Represents a time interval, encoded as a Timestamp start (inclusive) and a
Timestamp end (exclusive). The start must be less than or equal to the end.
When the start equals the end, the interval is empty (matches no time). When
both start and end are unspecified, the interval matches any time.
Corresponds to the JSON property salePriceEffectiveDate
463 464 465 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 463 def sale_price_effective_date @sale_price_effective_date end |
#sell_on_google_quantity ⇒ Fixnum
The quantity of the product that is available for selling on Google. Supported
only for online products.
Corresponds to the JSON property sellOnGoogleQuantity
469 470 471 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 469 def sell_on_google_quantity @sell_on_google_quantity end |
#shipping ⇒ Array<Google::Apis::MerchantapiProductsV1beta::Shipping>
Shipping rules.
Corresponds to the JSON property shipping
474 475 476 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 474 def shipping @shipping end |
#shipping_height ⇒ Google::Apis::MerchantapiProductsV1beta::ShippingDimension
The ShippingDimension of the product.
Corresponds to the JSON property shippingHeight
479 480 481 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 479 def shipping_height @shipping_height end |
#shipping_label ⇒ String
The shipping label of the product, used to group product in account-level
shipping rules.
Corresponds to the JSON property shippingLabel
485 486 487 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 485 def shipping_label @shipping_label end |
#shipping_length ⇒ Google::Apis::MerchantapiProductsV1beta::ShippingDimension
The ShippingDimension of the product.
Corresponds to the JSON property shippingLength
490 491 492 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 490 def shipping_length @shipping_length end |
#shipping_weight ⇒ Google::Apis::MerchantapiProductsV1beta::ShippingWeight
The ShippingWeight of the product.
Corresponds to the JSON property shippingWeight
495 496 497 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 495 def shipping_weight @shipping_weight end |
#shipping_width ⇒ Google::Apis::MerchantapiProductsV1beta::ShippingDimension
The ShippingDimension of the product.
Corresponds to the JSON property shippingWidth
500 501 502 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 500 def shipping_width @shipping_width end |
#shopping_ads_excluded_countries ⇒ Array<String>
List of country codes (ISO 3166-1 alpha-2) to exclude the offer from Shopping Ads destination.
Countries from this list are removed from countries configured in data source
settings.
Corresponds to the JSON property shoppingAdsExcludedCountries
508 509 510 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 508 def shopping_ads_excluded_countries @shopping_ads_excluded_countries end |
#size ⇒ String
Size of the item. Only one value is allowed. For variants with different sizes,
insert a separate product for each size with the same itemGroupId value,
see Size.
Corresponds to the JSON property size
515 516 517 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 515 def size @size end |
#size_system ⇒ String
System in which the size is specified. Recommended for apparel items. For
example, "US", "UK", "DE". For more information, see Size system.
Corresponds to the JSON property sizeSystem
522 523 524 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 522 def size_system @size_system end |
#size_types ⇒ Array<String>
The cut of the item. It can be used to represent combined size types for
apparel items. Maximum two of size types can be provided, see Size type. For example, "petite", "
plus size".
Corresponds to the JSON property sizeTypes
530 531 532 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 530 def size_types @size_types end |
#structured_description ⇒ Google::Apis::MerchantapiProductsV1beta::ProductStructuredDescription
Structured description, for algorithmically (AI)-generated descriptions.
Corresponds to the JSON property structuredDescription
535 536 537 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 535 def structured_description @structured_description end |
#structured_title ⇒ Google::Apis::MerchantapiProductsV1beta::ProductStructuredTitle
Structured title, for algorithmically (AI)-generated titles.
Corresponds to the JSON property structuredTitle
540 541 542 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 540 def structured_title @structured_title end |
#subscription_cost ⇒ Google::Apis::MerchantapiProductsV1beta::SubscriptionCost
The SubscriptionCost of the product.
Corresponds to the JSON property subscriptionCost
545 546 547 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 545 def subscription_cost @subscription_cost end |
#sustainability_incentives ⇒ Array<Google::Apis::MerchantapiProductsV1beta::ProductSustainabilityIncentive>
The list of sustainability incentive programs.
Corresponds to the JSON property sustainabilityIncentives
550 551 552 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 550 def sustainability_incentives @sustainability_incentives end |
#tax_category ⇒ String
The tax category of the
product.
Corresponds to the JSON property taxCategory
556 557 558 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 556 def tax_category @tax_category end |
#taxes ⇒ Array<Google::Apis::MerchantapiProductsV1beta::Tax>
Tax information.
Corresponds to the JSON property taxes
561 562 563 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 561 def taxes @taxes end |
#title ⇒ String
Title of the item.
Corresponds to the JSON property title
566 567 568 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 566 def title @title end |
#transit_time_label ⇒ String
The transit time label of the product, used to group product in account-level
transit time tables.
Corresponds to the JSON property transitTimeLabel
572 573 574 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 572 def transit_time_label @transit_time_label end |
#unit_pricing_base_measure ⇒ Google::Apis::MerchantapiProductsV1beta::UnitPricingBaseMeasure
The UnitPricingBaseMeasure of the product.
Corresponds to the JSON property unitPricingBaseMeasure
577 578 579 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 577 def unit_pricing_base_measure @unit_pricing_base_measure end |
#unit_pricing_measure ⇒ Google::Apis::MerchantapiProductsV1beta::UnitPricingMeasure
The UnitPricingMeasure of the product.
Corresponds to the JSON property unitPricingMeasure
582 583 584 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 582 def unit_pricing_measure @unit_pricing_measure end |
#virtual_model_link ⇒ String
URL of the 3D image of the item. See the Help Center article for more information.
Corresponds to the JSON property virtualModelLink
588 589 590 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 588 def virtual_model_link @virtual_model_link end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 595 def update!(**args) @additional_image_links = args[:additional_image_links] if args.key?(:additional_image_links) @ads_grouping = args[:ads_grouping] if args.key?(:ads_grouping) @ads_labels = args[:ads_labels] if args.key?(:ads_labels) @ads_redirect = args[:ads_redirect] if args.key?(:ads_redirect) @adult = args[:adult] if args.key?(:adult) @age_group = args[:age_group] if args.key?(:age_group) @auto_pricing_min_price = args[:auto_pricing_min_price] if args.key?(:auto_pricing_min_price) @availability = args[:availability] if args.key?(:availability) @availability_date = args[:availability_date] if args.key?(:availability_date) @brand = args[:brand] if args.key?(:brand) @canonical_link = args[:canonical_link] if args.key?(:canonical_link) @certifications = args[:certifications] if args.key?(:certifications) @cloud_export_additional_properties = args[:cloud_export_additional_properties] if args.key?(:cloud_export_additional_properties) @color = args[:color] if args.key?(:color) @condition = args[:condition] if args.key?(:condition) @cost_of_goods_sold = args[:cost_of_goods_sold] if args.key?(:cost_of_goods_sold) @custom_label0 = args[:custom_label0] if args.key?(:custom_label0) @custom_label1 = args[:custom_label1] if args.key?(:custom_label1) @custom_label2 = args[:custom_label2] if args.key?(:custom_label2) @custom_label3 = args[:custom_label3] if args.key?(:custom_label3) @custom_label4 = args[:custom_label4] if args.key?(:custom_label4) @description = args[:description] if args.key?(:description) @disclosure_date = args[:disclosure_date] if args.key?(:disclosure_date) @display_ads_id = args[:display_ads_id] if args.key?(:display_ads_id) @display_ads_link = args[:display_ads_link] if args.key?(:display_ads_link) @display_ads_similar_ids = args[:display_ads_similar_ids] if args.key?(:display_ads_similar_ids) @display_ads_title = args[:display_ads_title] if args.key?(:display_ads_title) @display_ads_value = args[:display_ads_value] if args.key?(:display_ads_value) @energy_efficiency_class = args[:energy_efficiency_class] if args.key?(:energy_efficiency_class) @excluded_destinations = args[:excluded_destinations] if args.key?(:excluded_destinations) @expiration_date = args[:expiration_date] if args.key?(:expiration_date) @external_seller_id = args[:external_seller_id] if args.key?(:external_seller_id) @free_shipping_threshold = args[:free_shipping_threshold] if args.key?(:free_shipping_threshold) @gender = args[:gender] if args.key?(:gender) @google_product_category = args[:google_product_category] if args.key?(:google_product_category) @gtin = args[:gtin] if args.key?(:gtin) @gtins = args[:gtins] if args.key?(:gtins) @identifier_exists = args[:identifier_exists] if args.key?(:identifier_exists) @image_link = args[:image_link] if args.key?(:image_link) @included_destinations = args[:included_destinations] if args.key?(:included_destinations) @installment = args[:installment] if args.key?(:installment) @is_bundle = args[:is_bundle] if args.key?(:is_bundle) @item_group_id = args[:item_group_id] if args.key?(:item_group_id) @lifestyle_image_links = args[:lifestyle_image_links] if args.key?(:lifestyle_image_links) @link = args[:link] if args.key?(:link) @link_template = args[:link_template] if args.key?(:link_template) @loyalty_points = args[:loyalty_points] if args.key?(:loyalty_points) @loyalty_programs = args[:loyalty_programs] if args.key?(:loyalty_programs) @material = args[:material] if args.key?(:material) @max_energy_efficiency_class = args[:max_energy_efficiency_class] if args.key?(:max_energy_efficiency_class) @max_handling_time = args[:max_handling_time] if args.key?(:max_handling_time) @maximum_retail_price = args[:maximum_retail_price] if args.key?(:maximum_retail_price) @min_energy_efficiency_class = args[:min_energy_efficiency_class] if args.key?(:min_energy_efficiency_class) @min_handling_time = args[:min_handling_time] if args.key?(:min_handling_time) @mobile_link = args[:mobile_link] if args.key?(:mobile_link) @mobile_link_template = args[:mobile_link_template] if args.key?(:mobile_link_template) @mpn = args[:mpn] if args.key?(:mpn) @multipack = args[:multipack] if args.key?(:multipack) @pattern = args[:pattern] if args.key?(:pattern) @pause = args[:pause] if args.key?(:pause) @pickup_method = args[:pickup_method] if args.key?(:pickup_method) @pickup_sla = args[:pickup_sla] if args.key?(:pickup_sla) @price = args[:price] if args.key?(:price) @product_details = args[:product_details] if args.key?(:product_details) @product_height = args[:product_height] if args.key?(:product_height) @product_highlights = args[:product_highlights] if args.key?(:product_highlights) @product_length = args[:product_length] if args.key?(:product_length) @product_types = args[:product_types] if args.key?(:product_types) @product_weight = args[:product_weight] if args.key?(:product_weight) @product_width = args[:product_width] if args.key?(:product_width) @promotion_ids = args[:promotion_ids] if args.key?(:promotion_ids) @sale_price = args[:sale_price] if args.key?(:sale_price) @sale_price_effective_date = args[:sale_price_effective_date] if args.key?(:sale_price_effective_date) @sell_on_google_quantity = args[:sell_on_google_quantity] if args.key?(:sell_on_google_quantity) @shipping = args[:shipping] if args.key?(:shipping) @shipping_height = args[:shipping_height] if args.key?(:shipping_height) @shipping_label = args[:shipping_label] if args.key?(:shipping_label) @shipping_length = args[:shipping_length] if args.key?(:shipping_length) @shipping_weight = args[:shipping_weight] if args.key?(:shipping_weight) @shipping_width = args[:shipping_width] if args.key?(:shipping_width) @shopping_ads_excluded_countries = args[:shopping_ads_excluded_countries] if args.key?(:shopping_ads_excluded_countries) @size = args[:size] if args.key?(:size) @size_system = args[:size_system] if args.key?(:size_system) @size_types = args[:size_types] if args.key?(:size_types) @structured_description = args[:structured_description] if args.key?(:structured_description) @structured_title = args[:structured_title] if args.key?(:structured_title) @subscription_cost = args[:subscription_cost] if args.key?(:subscription_cost) @sustainability_incentives = args[:sustainability_incentives] if args.key?(:sustainability_incentives) @tax_category = args[:tax_category] if args.key?(:tax_category) @taxes = args[:taxes] if args.key?(:taxes) @title = args[:title] if args.key?(:title) @transit_time_label = args[:transit_time_label] if args.key?(:transit_time_label) @unit_pricing_base_measure = args[:unit_pricing_base_measure] if args.key?(:unit_pricing_base_measure) @unit_pricing_measure = args[:unit_pricing_measure] if args.key?(:unit_pricing_measure) @virtual_model_link = args[:virtual_model_link] if args.key?(:virtual_model_link) end |