Class: Google::Apis::MerchantapiProductsV1beta::ItemLevelIssue
- Inherits:
-
Object
- Object
- Google::Apis::MerchantapiProductsV1beta::ItemLevelIssue
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/merchantapi_products_v1beta/classes.rb,
lib/google/apis/merchantapi_products_v1beta/representations.rb,
lib/google/apis/merchantapi_products_v1beta/representations.rb
Overview
The ItemLevelIssue of the product status.
Instance Attribute Summary collapse
-
#applicable_countries ⇒ Array<String>
List of country codes (ISO 3166-1 alpha-2) where issue applies to the offer.
-
#attribute ⇒ String
The attribute's name, if the issue is caused by a single attribute.
-
#code ⇒ String
The error code of the issue.
-
#description ⇒ String
A short issue description in English.
-
#detail ⇒ String
A detailed issue description in English.
-
#documentation ⇒ String
The URL of a web page to help with resolving this issue.
-
#reporting_context ⇒ String
The reporting context the issue applies to.
-
#resolution ⇒ String
Whether the issue can be resolved by the business.
-
#severity ⇒ String
How this issue affects serving of the offer.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ItemLevelIssue
constructor
A new instance of ItemLevelIssue.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ItemLevelIssue
Returns a new instance of ItemLevelIssue.
1069 1070 1071 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 1069 def initialize(**args) update!(**args) end |
Instance Attribute Details
#applicable_countries ⇒ Array<String>
List of country codes (ISO 3166-1 alpha-2) where issue applies to the offer.
Corresponds to the JSON property applicableCountries
1027 1028 1029 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 1027 def applicable_countries @applicable_countries end |
#attribute ⇒ String
The attribute's name, if the issue is caused by a single attribute.
Corresponds to the JSON property attribute
1032 1033 1034 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 1032 def attribute @attribute end |
#code ⇒ String
The error code of the issue.
Corresponds to the JSON property code
1037 1038 1039 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 1037 def code @code end |
#description ⇒ String
A short issue description in English.
Corresponds to the JSON property description
1042 1043 1044 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 1042 def description @description end |
#detail ⇒ String
A detailed issue description in English.
Corresponds to the JSON property detail
1047 1048 1049 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 1047 def detail @detail end |
#documentation ⇒ String
The URL of a web page to help with resolving this issue.
Corresponds to the JSON property documentation
1052 1053 1054 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 1052 def documentation @documentation end |
#reporting_context ⇒ String
The reporting context the issue applies to.
Corresponds to the JSON property reportingContext
1057 1058 1059 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 1057 def reporting_context @reporting_context end |
#resolution ⇒ String
Whether the issue can be resolved by the business.
Corresponds to the JSON property resolution
1062 1063 1064 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 1062 def resolution @resolution end |
#severity ⇒ String
How this issue affects serving of the offer.
Corresponds to the JSON property severity
1067 1068 1069 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 1067 def severity @severity end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1074 1075 1076 1077 1078 1079 1080 1081 1082 1083 1084 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 1074 def update!(**args) @applicable_countries = args[:applicable_countries] if args.key?(:applicable_countries) @attribute = args[:attribute] if args.key?(:attribute) @code = args[:code] if args.key?(:code) @description = args[:description] if args.key?(:description) @detail = args[:detail] if args.key?(:detail) @documentation = args[:documentation] if args.key?(:documentation) @reporting_context = args[:reporting_context] if args.key?(:reporting_context) @resolution = args[:resolution] if args.key?(:resolution) @severity = args[:severity] if args.key?(:severity) end |