Class: Google::Apis::MerchantapiProductsV1beta::MerchantService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::MerchantapiProductsV1beta::MerchantService
- Defined in:
- lib/google/apis/merchantapi_products_v1beta/service.rb
Overview
Merchant API
Programmatically manage your Merchant Center Accounts.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://merchantapi.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#delete_account_product_input(name, data_source: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MerchantapiProductsV1beta::Empty
Deletes a product input from your Merchant Center account.
-
#get_account_product(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MerchantapiProductsV1beta::Product
Retrieves the processed product from your Merchant Center account.
-
#initialize ⇒ MerchantService
constructor
A new instance of MerchantService.
- #insert_account_product_input(parent, product_input_object = nil, data_source: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MerchantapiProductsV1beta::ProductInput
-
#list_account_products(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MerchantapiProductsV1beta::ListProductsResponse
Lists the processed products in your Merchant Center account.
-
#patch_account_product_input(name, product_input_object = nil, data_source: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MerchantapiProductsV1beta::ProductInput
Updates the existing product input in your Merchant Center account.
Constructor Details
#initialize ⇒ MerchantService
Returns a new instance of MerchantService.
47 48 49 50 51 52 |
# File 'lib/google/apis/merchantapi_products_v1beta/service.rb', line 47 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-merchantapi_products_v1beta', client_version: Google::Apis::MerchantapiProductsV1beta::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
40 41 42 |
# File 'lib/google/apis/merchantapi_products_v1beta/service.rb', line 40 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
45 46 47 |
# File 'lib/google/apis/merchantapi_products_v1beta/service.rb', line 45 def quota_user @quota_user end |
Instance Method Details
#delete_account_product_input(name, data_source: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MerchantapiProductsV1beta::Empty
Deletes a product input from your Merchant Center account. After inserting, updating, or deleting a product input, it may take several minutes before the processed product can be retrieved.
102 103 104 105 106 107 108 109 110 111 |
# File 'lib/google/apis/merchantapi_products_v1beta/service.rb', line 102 def delete_account_product_input(name, data_source: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'products/v1beta/{+name}', ) command.response_representation = Google::Apis::MerchantapiProductsV1beta::Empty::Representation command.response_class = Google::Apis::MerchantapiProductsV1beta::Empty command.params['name'] = name unless name.nil? command.query['dataSource'] = data_source unless data_source.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_account_product(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MerchantapiProductsV1beta::Product
Retrieves the processed product from your Merchant Center account. After inserting, updating, or deleting a product input, it may take several minutes before the updated final product can be retrieved.
282 283 284 285 286 287 288 289 290 |
# File 'lib/google/apis/merchantapi_products_v1beta/service.rb', line 282 def get_account_product(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'products/v1beta/{+name}', ) command.response_representation = Google::Apis::MerchantapiProductsV1beta::Product::Representation command.response_class = Google::Apis::MerchantapiProductsV1beta::Product command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#insert_account_product_input(parent, product_input_object = nil, data_source: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MerchantapiProductsV1beta::ProductInput
Uploads a product input to your Merchant Center account. You must have a products data source to be able to insert a product. The unique identifier of the data source is passed as a query parameter in the request URL. If a product input with the same contentLanguage, offerId, and dataSource already exists, then the product input inserted by this method replaces that entry. After inserting, updating, or deleting a product input, it may take several minutes before the processed product can be retrieved.
150 151 152 153 154 155 156 157 158 159 160 161 |
# File 'lib/google/apis/merchantapi_products_v1beta/service.rb', line 150 def insert_account_product_input(parent, product_input_object = nil, data_source: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'products/v1beta/{+parent}/productInputs:insert', ) command.request_representation = Google::Apis::MerchantapiProductsV1beta::ProductInput::Representation command.request_object = product_input_object command.response_representation = Google::Apis::MerchantapiProductsV1beta::ProductInput::Representation command.response_class = Google::Apis::MerchantapiProductsV1beta::ProductInput command.params['parent'] = parent unless parent.nil? command.query['dataSource'] = data_source unless data_source.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_account_products(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MerchantapiProductsV1beta::ListProductsResponse
Lists the processed products in your Merchant Center account. The response
might contain fewer items than specified by pageSize. Rely on pageToken to
determine if there are more items to be requested. After inserting, updating,
or deleting a product input, it may take several minutes before the updated
processed product can be retrieved.
325 326 327 328 329 330 331 332 333 334 335 |
# File 'lib/google/apis/merchantapi_products_v1beta/service.rb', line 325 def list_account_products(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'products/v1beta/{+parent}/products', ) command.response_representation = Google::Apis::MerchantapiProductsV1beta::ListProductsResponse::Representation command.response_class = Google::Apis::MerchantapiProductsV1beta::ListProductsResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_account_product_input(name, product_input_object = nil, data_source: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MerchantapiProductsV1beta::ProductInput
Updates the existing product input in your Merchant Center account. The name
of the product input to update is taken from the name field within the
ProductInput resource. After inserting, updating, or deleting a product input,
it may take several minutes before the processed product can be retrieved.
223 224 225 226 227 228 229 230 231 232 233 234 235 |
# File 'lib/google/apis/merchantapi_products_v1beta/service.rb', line 223 def patch_account_product_input(name, product_input_object = nil, data_source: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'products/v1beta/{+name}', ) command.request_representation = Google::Apis::MerchantapiProductsV1beta::ProductInput::Representation command.request_object = product_input_object command.response_representation = Google::Apis::MerchantapiProductsV1beta::ProductInput::Representation command.response_class = Google::Apis::MerchantapiProductsV1beta::ProductInput command.params['name'] = name unless name.nil? command.query['dataSource'] = data_source unless data_source.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |