Class: Google::Apis::MerchantapiProductsV1beta::ProductStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/merchantapi_products_v1beta/classes.rb,
lib/google/apis/merchantapi_products_v1beta/representations.rb,
lib/google/apis/merchantapi_products_v1beta/representations.rb

Overview

The status of a product, data validation issues, that is, information about a product computed asynchronously.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ProductStatus

Returns a new instance of ProductStatus.



1662
1663
1664
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 1662

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_dateString

Date on which the item has been created, in ISO 8601 format. Corresponds to the JSON property creationDate

Returns:

  • (String)


1638
1639
1640
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 1638

def creation_date
  @creation_date
end

#destination_statusesArray<Google::Apis::MerchantapiProductsV1beta::DestinationStatus>

The intended destinations for the product. Corresponds to the JSON property destinationStatuses



1643
1644
1645
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 1643

def destination_statuses
  @destination_statuses
end

#google_expiration_dateString

Date on which the item expires, in ISO 8601 format. Corresponds to the JSON property googleExpirationDate

Returns:

  • (String)


1649
1650
1651
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 1649

def google_expiration_date
  @google_expiration_date
end

#item_level_issuesArray<Google::Apis::MerchantapiProductsV1beta::ItemLevelIssue>

A list of all issues associated with the product. Corresponds to the JSON property itemLevelIssues



1654
1655
1656
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 1654

def item_level_issues
  @item_level_issues
end

#last_update_dateString

Date on which the item has been last updated, in ISO 8601 format. Corresponds to the JSON property lastUpdateDate

Returns:

  • (String)


1660
1661
1662
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 1660

def last_update_date
  @last_update_date
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1667
1668
1669
1670
1671
1672
1673
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 1667

def update!(**args)
  @creation_date = args[:creation_date] if args.key?(:creation_date)
  @destination_statuses = args[:destination_statuses] if args.key?(:destination_statuses)
  @google_expiration_date = args[:google_expiration_date] if args.key?(:google_expiration_date)
  @item_level_issues = args[:item_level_issues] if args.key?(:item_level_issues)
  @last_update_date = args[:last_update_date] if args.key?(:last_update_date)
end