Class: Google::Apis::MerchantapiProductsV1beta::ProductStatusChangeMessage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/merchantapi_products_v1beta/classes.rb,
lib/google/apis/merchantapi_products_v1beta/representations.rb,
lib/google/apis/merchantapi_products_v1beta/representations.rb

Overview

The message that the merchant will receive to notify about product status change event

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ProductStatusChangeMessage

Returns a new instance of ProductStatusChangeMessage.



1732
1733
1734
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 1732

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#accountString

The target account that owns the entity that changed. Format : accounts/ merchant_id` Corresponds to the JSON propertyaccount`

Returns:

  • (String)


1685
1686
1687
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 1685

def 
  @account
end

#attributeString

The attribute in the resource that changed, in this case it will be always Status. Corresponds to the JSON property attribute

Returns:

  • (String)


1691
1692
1693
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 1691

def attribute
  @attribute
end

#changesArray<Google::Apis::MerchantapiProductsV1beta::ProductChange>

A message to describe the change that happened to the product Corresponds to the JSON property changes



1696
1697
1698
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 1696

def changes
  @changes
end

#event_timeString

The time at which the event was generated. If you want to order the notification messages you receive you should rely on this field not on the order of receiving the notifications. Corresponds to the JSON property eventTime

Returns:

  • (String)


1703
1704
1705
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 1703

def event_time
  @event_time
end

#expiration_timeString

Optional. The product expiration time. This field will not be set if the notification is sent for a product deletion event. Corresponds to the JSON property expirationTime

Returns:

  • (String)


1709
1710
1711
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 1709

def expiration_time
  @expiration_time
end

#managing_accountString

The account that manages the merchant's account. can be the same as merchant id if it is standalone account. Format : accounts/service_provider_id` Corresponds to the JSON propertymanagingAccount`

Returns:

  • (String)


1715
1716
1717
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 1715

def 
  @managing_account
end

#resourceString

The product name. Format: accounts/account/products/product` Corresponds to the JSON propertyresource`

Returns:

  • (String)


1720
1721
1722
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 1720

def resource
  @resource
end

#resource_idString

The product id. Corresponds to the JSON property resourceId

Returns:

  • (String)


1725
1726
1727
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 1725

def resource_id
  @resource_id
end

#resource_typeString

The resource that changed, in this case it will always be Product. Corresponds to the JSON property resourceType

Returns:

  • (String)


1730
1731
1732
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 1730

def resource_type
  @resource_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1737
1738
1739
1740
1741
1742
1743
1744
1745
1746
1747
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 1737

def update!(**args)
  @account = args[:account] if args.key?(:account)
  @attribute = args[:attribute] if args.key?(:attribute)
  @changes = args[:changes] if args.key?(:changes)
  @event_time = args[:event_time] if args.key?(:event_time)
  @expiration_time = args[:expiration_time] if args.key?(:expiration_time)
  @managing_account = args[:managing_account] if args.key?(:managing_account)
  @resource = args[:resource] if args.key?(:resource)
  @resource_id = args[:resource_id] if args.key?(:resource_id)
  @resource_type = args[:resource_type] if args.key?(:resource_type)
end