Class: Google::Apis::MerchantapiProductsV1beta::ShippingWeight
- Inherits:
-
Object
- Object
- Google::Apis::MerchantapiProductsV1beta::ShippingWeight
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/merchantapi_products_v1beta/classes.rb,
lib/google/apis/merchantapi_products_v1beta/representations.rb,
lib/google/apis/merchantapi_products_v1beta/representations.rb
Overview
The ShippingWeight of the product.
Instance Attribute Summary collapse
-
#unit ⇒ String
The unit of value.
-
#value ⇒ Float
The weight of the product used to calculate the shipping cost of the item.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ShippingWeight
constructor
A new instance of ShippingWeight.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ShippingWeight
Returns a new instance of ShippingWeight.
2042 2043 2044 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 2042 def initialize(**args) update!(**args) end |
Instance Attribute Details
#unit ⇒ String
The unit of value.
Corresponds to the JSON property unit
2035 2036 2037 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 2035 def unit @unit end |
#value ⇒ Float
The weight of the product used to calculate the shipping cost of the item.
Corresponds to the JSON property value
2040 2041 2042 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 2040 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2047 2048 2049 2050 |
# File 'lib/google/apis/merchantapi_products_v1beta/classes.rb', line 2047 def update!(**args) @unit = args[:unit] if args.key?(:unit) @value = args[:value] if args.key?(:value) end |